@@ -1,15 +1,15 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cabal-helper
-version: 0.6.3.1
-id: cabal-helper-0.6.3.1-512cee1d780890ae55b68b9cff633e01
-key: cabal_3g6YHQHZFzd4tYIv6IHNqX
+version: 0.7.1.0
+id: cabal-helper-0.7.1.0-c4ff04fcd83476790cdcd5bdb674c574
+key: cabal_I8E5olMHM9xFkEjNn6eY0A
 license: AGPL-3
 maintainer: dxld@darkboxed.org
 synopsis: Simple interface to some of Cabal'\''s configuration state used by ghc-mod
 description:
-    @cabal-helper@ provides a library which wraps the internal use of
-    anexecutable to lift the restrictions imposed by linking against versions of
+    @cabal-helper@ provides a library which wraps the internal use of an
+    executable to lift the restrictions imposed by linking against versions of
     GHC before @7.10@. This has the pleasant side effect of isolating the user
     from having to deal with Cabal version changes manually as @cabal-helper@
     can simply recompile it'\''s helper program automatically as needed.
@@ -40,10 +40,10 @@ exposed-modules:
 hidden-modules: Paths_cabal_helper CabalHelper.Types
                 CabalHelper.Sandbox
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/cabal-helper-0.6.3.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/cabal-helper-0.6.3.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/cabal-helper-0.6.3.1
-hs-libraries: HScabal-helper-0.6.3.1-3g6YHQHZFzd4tYIv6IHNqX
+import-dirs: /usr/lib/ghc-7.10.3/site-local/cabal-helper-0.7.1.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/cabal-helper-0.7.1.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/cabal-helper-0.7.1.0
+hs-libraries: HScabal-helper-0.7.1.0-I8E5olMHM9xFkEjNn6eY0A
 depends:
     Cabal-1.22.5.0-9b2e7feff1fc55070a0a783f283ee9b6
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
